function w = TRAPEZ(f,a,b,N)
% w = TRAPEZ(f,a,b,N)
%
% summierte Trapezregel zur Funktion f auf dem Intervall [a,b]
% und äquidistanten Unterteilung
% x_i = a + i * h, i = 0,1,...,N;   h = (b-a)/N 
%
% Input
% f       auszuwertende Funktion im Intervall [a,b]
% a,b     Intervallgrenzen a,b
% N       Anzahl Unterteilungen. Das Intervall [a,b] wird in N äquidistante
%         Teilstücke eingeteilt
%
% Output  
% w       Wert der summierten Regel


